# ML Belt
The machine learning and data science utility belt.

Read the docs: https://ml-belt.readthedocs.io

We recommend that you have Anaconda installed: https://anaconda.org/


## Instalation
You can install using pip:

    pip install ml_belt
